@@ -1,6 +1,6 @@
 package TPath;
 {
-  $TPath::VERSION = '1.004';
+  $TPath::VERSION = '1.005';
 }
 
 # ABSTRACT: general purpose path languages for trees
@@ -17,7 +17,7 @@ TPath - general purpose path languages for trees
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -754,14 +754,18 @@ and preceding filters. For example
   //*[0]
 
 picks all nodes that are the first child of their parent (also the root, which has no parent).
+This is distinct from C</descendant-or-self::*[0]>, which will simply pick the root.
 
   //a[0]
 
-picks all nodes that are the first child of an C<a> node.
+picks all nodes that are the first child of an C<a> node. This is distinct from C</descendant-or-self::a[0]>, 
+where the only node returned will simply be the first node picked on this axis.
 
   //a[@foo][0]
 
-picks all nodes that are the first child of an C<a> node having the property C<@foo>.
+picks all nodes that are the first child of an C<a> node having the property C<@foo>. This is
+distinct from C</descendant-or-self::a[@foo][0]>, which will pick only the first C<a> node with
+the C<@foo> property.
 
 These predicates are all "inner" predicates. It is also possible to specify "outer" predicates, like so
 
@@ -774,7 +778,8 @@ to a node's similar siblings. So the first expression picks the first node which
 child of its parent; the second picks the first node anywhere that is the first child of an C<a>
 node; the third picks the first node anywhere that is the first C<@foo> child node of an C<a> node.
 
-Any predicate may be either inner or outer, but the distinction is most relevant to index predicates.
+Any predicate may be either inner or outer, but the distinction is most relevant to index predicates for
+steps with the C<//> separator.
 
 =head3 Path Predicates
 
@@ -1460,7 +1465,7 @@ All the places where one may use the C<\> escape character to protect a special
 a string one may also use one of the escape sequences understood by tpath, which are
 just those understood by JSON. These are
 
-=over4
+=over 4
 
 =item \t
 
