@@ -1,6 +1,6 @@
 package TPath::Predicate::Index;
 {
-  $TPath::Predicate::Index::VERSION = '1.004';
+  $TPath::Predicate::Index::VERSION = '1.005';
 }
 
 # ABSTRACT: implements the C<[0]> in C<//a/b[0]>
@@ -17,6 +17,9 @@ has idx => ( is => 'ro', isa => 'Int', required => 1 );
 
 has f => (is => 'ro', does => 'TPath::Forester', required => 1);
 
+# needed for lazy specification of algorithm
+has _anywhere => (is=>'rw', isa => 'Bool', default => 0);
+
 has algorithm => (
     is      => 'ro',
     isa     => 'CodeRef',
@@ -32,7 +35,7 @@ has algorithm => (
         return sub {
             return shift->[$i] // ();
           }
-          if $self->outer;
+          if $self->outer or !$self->_anywhere;
         return sub {
             my $c = shift;
             my ( $index, %tally, @ret );
@@ -107,7 +110,7 @@ TPath::Predicate::Index - implements the C<[0]> in C<//a/b[0]>
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 DESCRIPTION
 
